@@ -3,13 +3,13 @@ from typing import Union
 from py_desc.base import Base
 
 
-class NotNegativeFloat(Base):
+class PositiveFloat(Base):
 
     def __get__(self, instance, owner):
         return getattr(instance, self.name)
 
     def __set__(self, instance, value):
-        if not isinstance(value, int):
+        if not isinstance(value, float):
             raise ValueError('Must be float')
         if value < 0:
             raise ValueError('Cannot be negative')
@@ -19,13 +19,13 @@ class NotNegativeFloat(Base):
         self.name = f'_{name.lower()}'
 
 
-class NotPositiveFloat(Base):
+class NegativeFloat(Base):
 
     def __get__(self, instance, owner):
         return getattr(instance, self.name)
 
     def __set__(self, instance, value):
-        if not isinstance(value, int):
+        if not isinstance(value, float):
             raise ValueError('Must be float')
         if value >= 0:
             raise ValueError('Cannot be positive')
@@ -37,8 +37,8 @@ class NotPositiveFloat(Base):
 
 class CustomFloat(Base):
 
-    def __init__(self, first_value: Union[float, int], last_value: Union[int, float]) -> None:
-        if not (isinstance(first_value, Union[float, int]) and isinstance(last_value, Union[float, int])):
+    def __init__(self, first_value: Union[float, int] = None, last_value: Union[int, float] = None) -> None:
+        if not (isinstance(first_value, Union[float, int, None]) and isinstance(last_value, Union[float, int, None])):
             raise AttributeError('Cannot assign parameters for float field')
         if first_value is not None and last_value is not None:
             if first_value > last_value:
@@ -65,7 +65,8 @@ class CustomFloat(Base):
         else:
             if self.first_value < value < self.last_value:
                 setattr(instance, self.name, value)
-            raise ValueError(f'Cannot be not in range [{self.first_value}:{self.last_value}]')
+            else:
+                raise ValueError(f'Cannot be not in range [{self.first_value}:{self.last_value}]')
         setattr(instance, self.name, value)
 
     def __set_name__(self, owner, name):
