@@ -1,7 +1,9 @@
+from typing import Union
+
 from py_desc.base import Base
 
 
-class NotNegativeInteger(Base):
+class PositiveInteger(Base):
 
     def __get__(self, instance, owner):
         return getattr(instance, self.name)
@@ -17,7 +19,7 @@ class NotNegativeInteger(Base):
         self.name = f'_{name.lower()}'
 
 
-class NotPositiveInteger(Base):
+class NegativeInteger(Base):
 
     def __get__(self, instance, owner):
         return getattr(instance, self.name)
@@ -35,8 +37,8 @@ class NotPositiveInteger(Base):
 
 class CustomInteger(Base):
 
-    def __init__(self, first_value: int, last_value: int) -> None:
-        if not (isinstance(first_value, int) and isinstance(last_value, int)):
+    def __init__(self, first_value: int = None, last_value: int = None) -> None:
+        if not (isinstance(first_value, Union[int, None]) and isinstance(last_value, Union[int, None])):
             raise AttributeError('Cannot assign parameters for integer field')
         if first_value is not None and last_value is not None:
             if first_value > last_value:
@@ -63,7 +65,8 @@ class CustomInteger(Base):
         else:
             if self.first_value < value < self.last_value:
                 setattr(instance, self.name, value)
-            raise ValueError(f'Cannot be not in range [{self.first_value}:{self.last_value}]')
+            else:
+                raise ValueError(f'Cannot be not in range [{self.first_value}:{self.last_value}]')
         setattr(instance, self.name, value)
 
     def __set_name__(self, owner, name):
